@@ -12,11 +12,15 @@ class ExcelUtil:
 
         *Prerequisties*
 
-        Openpyxl module of python should be installed using command "pip install openpyxl"
-        OpenPyxlLibrary must be imported.
+        1. Openpyxl module of python should be installed using command "pip install openpyxl"
+        
+        2. ExcelUtil written by Nagesh Nagaraja should be installed uding command 
+        "pip install robotframework-excelutil"
+        
+        3. ExcelUtil must be imported.
 
         Example:
-            | Library        | OpenpyxlLibrary        |
+            | Library        | ExcelUtil        |
             | Open Excel     | Filename with fullpath |
 
         """
@@ -43,7 +47,8 @@ class ExcelUtil:
         """
         Open excel from relative path
         Arguments:
-            | File             | Filename with relative path from current folder to open and test upon        |
+            | File             | Filename with relative path from project home directory 
+                                 to open and test upon        |
 
         Example:
         | Open Excel From Relative Path     |  ../../Data/data.xlsx  |
@@ -68,7 +73,7 @@ class ExcelUtil:
         Return sheetnames of the workbook
         Example:
         | Open Excel      |  C:\\Data\\ExcelTest.xlsx  |
-        | Get sheet names      |                                                     |
+        | Get sheet names      |
         """
         return self.wb.get_sheet_names()
 
@@ -95,7 +100,7 @@ class ExcelUtil:
 
     def get_sheet_count(self):
         """
-        Return the Row count of the given sheet
+        Return the Sheet count of the currently open Excel
         Example:
         | Open Excel      |  C:\\Data\\ExcelTest.xlsx  |
         | Get Sheet count     |
